NoteName

Enum NoteName 

pub enum NoteName {
    Do = 0,
    Re = 2,
    Mi = 4,
    Fa = 5,
    Sol = 7,
    La = 9,
    Si = 11,
}
Represents a note by name without a specific octave or accidental Supports both letters from A to G and traditional Do Re Mi … names

Variants



Do = 0



Re = 2



Mi = 4



Fa = 5



Sol = 7



La = 9



Si = 11

Implementations

Source

impl NoteName

pub const C: NoteName = NoteName::Do

pub const D: NoteName = NoteName::Re

pub const E: NoteName = NoteName::Mi

pub const F: NoteName = NoteName::Fa

pub const G: NoteName = NoteName::Sol

pub const A: NoteName = NoteName::La

pub const B: NoteName = NoteName::Si