pub struct u14(/* private fields */);Expand description
A 14-bit integer type.
Wraps the u16 type and ensures that the top two bits are always zero.
Implementations
Sourceimpl u14
impl u14
Sourcepub const fn new(raw: u16) -> u14
pub const fn new(raw: u16) -> u14
Creates a restricted int from its non-restricted counterpart by masking off the extra bits.
Sourcepub const fn from_int_lossy(raw: u16) -> u14
pub const fn from_int_lossy(raw: u16) -> u14
Creates a restricted int from its non-restricted counterpart by masking off the extra bits.
Sourcepub fn try_from(raw: u16) -> Option<u14>
pub fn try_from(raw: u16) -> Option<u14>
Returns Some if the raw integer is within range of the restricted integer, and
None otherwise.
Sourcepub fn as_int(self) -> u16
pub fn as_int(self) -> u16
Get the inner integer out of the wrapper. The inner integer is guaranteed to be in range of the restricted wrapper.
Sourcepub fn slice_try_from_int(raw: &[u16]) -> Option<&[u14]>
pub fn slice_try_from_int(raw: &[u16]) -> Option<&[u14]>
Cast a slice of raw integers to a slice of restricted integers, only if there are no out-of-range integers.
Sourcepub fn slice_from_int(raw: &[u16]) -> &[u14]
pub fn slice_from_int(raw: &[u16]) -> &[u14]
Cast a slice of raw integers to a slice of restricted integers.
The slice is truncated up to the first out-of-range integer, if there is any.
Sourcepub unsafe fn slice_from_int_unchecked(raw: &[u16]) -> &[u14]
pub unsafe fn slice_from_int_unchecked(raw: &[u16]) -> &[u14]
Cast a slice of raw integers to a slice of restricted integers.
Safety
The input slice must not contain any out-of-range integers.
Sourcepub fn slice_try_from_int_mut(raw: &mut [u16]) -> Option<&mut [u14]>
pub fn slice_try_from_int_mut(raw: &mut [u16]) -> Option<&mut [u14]>
Cast a slice of mutable raw integers to a slice of mutable restricted integers, only if there are no out-of-range integers.
Sourcepub fn slice_from_int_mut(raw: &mut [u16]) -> &mut [u14]
pub fn slice_from_int_mut(raw: &mut [u16]) -> &mut [u14]
Cast a slice of mutable raw integers to a slice of mutable restricted integers.
The slice is truncated up to the first out-of-range integer, if there is any.
Sourcepub unsafe fn slice_from_int_unchecked_mut(raw: &mut [u16]) -> &mut [u14]
pub unsafe fn slice_from_int_unchecked_mut(raw: &mut [u16]) -> &mut [u14]
Cast a slice of mutable raw integers to a slice of mutable restricted integers.
Safety
The input slice must not contain any out-of-range integers.
Sourcepub fn slice_as_int(slice: &[u14]) -> &[u16]
pub fn slice_as_int(slice: &[u14]) -> &[u16]
Cast a slice of restricted integers to the corresponding raw integers.
All integers are guaranteed to be within range of the restricted int.